@@ -3,10 +3,11 @@ package Text::Diff3::List;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.07';
-
 use base qw(Text::Diff3::ListMixin Text::Diff3::Base);
 
+use version; our $VERSION = '0.08';
+our $RCS_ID = q{$Id: List.pm 0.08 2010/02/16 06:29:23Z tociyuki Exp $};
+
 sub list { return $_[0]->{list} }
 
 sub initialize {
@@ -26,10 +27,16 @@ sub as_array {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Text::Diff3::List - a list of difference sets
 
+=head1 VERSION
+
+0.08
+
 =head1 SYNOPSIS
 
   use Text::Diff3;
@@ -37,13 +44,43 @@ Text::Diff3::List - a list of difference sets
   my $diff2 = $f->create_list2;
   my $diff3 = $f->create_list3;
 
+=head1 DESCRIPTION
+
+=head1 METHODS
+
+=over
+
+=item C<< $obj->as_array >>
+
+Returns the clone of array.
+
+=item C<< $obj->list >>
+
+Returns the body of array reference.
+
+=item C<< $obj->initialize >>
+
+Sets up the object.
+
+=back
+
+=head1 SEE ALSO
+
+L<Text::Diff3::ListMixin>
+
+=head1 COMPATIBILITY
+
+Use new function style interfaces introduced from version 0.08.
+This module remained for backward compatibility before version 0.07.
+This module is no longer maintenance after version 0.08.
+
 =head1 AUTHOR
 
 MIZUTANI Tociyuki C<< <tociyuki@gmail.com> >>.
 
-=head1 COPYRIGHT AND LICENSE
+=head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2009 MIZUTANI Tociyuki
+Copyright (C) 2010 MIZUTANI Tociyuki
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -51,3 +88,4 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
 =cut
+
